

SCSRecord
======================

.. currentmodule:: pyvo.dal.scs

.. autoclass:: SCSRecord
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SCSRecord.dec
      ~SCSRecord.id
      ~SCSRecord.ra

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: dec
   .. autoattribute:: id
   .. autoattribute:: ra

   
   

   
   
   